(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     37499,       1058]
NotebookOptionsPosition[     35833,        997]
NotebookOutlinePosition[     36191,       1013]
CellTagsIndexPosition[     36148,       1010]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData["Exit"], "Input",
 CellChangeTimes->{{3.571724013323646*^9, 3.571724013990407*^9}}],

Cell["\<\
Laplace - Fourier analysis of the Maxwell equations for NR/HEP2
David Hilditch\
\>", "Subtitle",
 CellChangeTimes->{{3.571724019725498*^9, 3.571724042683599*^9}, {
  3.577464953528824*^9, 3.5774649876405087`*^9}, {3.577465052102949*^9, 
  3.577465062679875*^9}}],

Cell[CellGroupData[{

Cell["Call Script", "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.457085214872101*^9, 3.457085217882016*^9}, 
   3.571724004293489*^9}],

Cell[BoxData[
 RowBox[{"<<", "Scripts/Maxwell_LF.m"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.455428340911338*^9, 3.455428350917323*^9}, {
  3.455436806927038*^9, 3.45543681826112*^9}, {3.4555119769139643`*^9, 
  3.455511983246038*^9}, {3.455517524963731*^9, 3.455517534577579*^9}, {
  3.457083052797737*^9, 3.457083053384137*^9}, {3.457090137369231*^9, 
  3.457090139416943*^9}, {3.571573281299361*^9, 3.571573314307479*^9}, {
  3.571573396964452*^9, 3.571573400772894*^9}, {3.5715755252773523`*^9, 
  3.571575560206378*^9}, {3.571723856969686*^9, 3.5717239357371893`*^9}, {
  3.571723967882468*^9, 3.571724004293645*^9}, {3.5717749735097027`*^9, 
  3.5717749812990713`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Examine symbol of the ODE system\
\>", "Text",
 CellChangeTimes->{{3.5717241496355743`*^9, 3.571724164038561*^9}, {
  3.5773806926691513`*^9, 3.577380694032426*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"M", "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.571681024403358*^9, 3.5716810277009077`*^9}, {
  3.57172417064141*^9, 3.571724173375864*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "\[Kappa]", "0", "0", "0", "0", "0", "0"},
     {
      RowBox[{"\[Kappa]", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          SuperscriptBox["sd", "2"], "\[Mu]\[CapitalPhi]"], "+", 
         SuperscriptBox["\[Omega]d", "2"]}], ")"}]}], "0", "0", "0", "0", "0",
       "0", "0"},
     {"0", "0", "0", "\[Kappa]", "0", "0", "0", "0"},
     {"0", 
      FractionBox[
       RowBox[{"sd", " ", "\[Kappa]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Mu]\[CapitalPhi]"}], ")"}]}], 
       "\[Mu]\[CapitalPhi]"], 
      RowBox[{"\[Kappa]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["sd", "2"], "+", 
         SuperscriptBox["\[Omega]d", "2"]}], ")"}]}], "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "\[Kappa]", "0", "0"},
     {
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "sd", " ", "\[Kappa]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Mu]\[CapitalPhi]"}], ")"}], " ", 
        "\[Omega]d"}], "\[Mu]\[CapitalPhi]"], "0", "0", "0", 
      RowBox[{"\[Kappa]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["sd", "2"], "+", 
         SuperscriptBox["\[Omega]d", "2"]}], ")"}]}], "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "\[Kappa]"},
     {"0", "0", "0", "0", "0", "0", 
      RowBox[{"\[Kappa]", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["sd", "2"], "+", 
         SuperscriptBox["\[Omega]d", "2"]}], ")"}]}], "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.57168102810224*^9, 3.571682570907713*^9, 3.571723985896097*^9, 
   3.571724073050564*^9, 3.5717241736291513`*^9, 3.571768483920035*^9, 
   3.5718371078811083`*^9, 3.571838741002726*^9, {3.5773806881645203`*^9, 
   3.57738069592243*^9}, 3.577380896185397*^9, 3.5773809890907593`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Examine solution. Verify that it works.", "Text",
 CellChangeTimes->{{3.5717241496355743`*^9, 3.571724164038561*^9}, {
  3.571724197717824*^9, 3.571724217796114*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GenSoln", "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.571724304521213*^9, 3.571724306415586*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {"\[Sigma]\[CapitalPhi]"},
      {
       RowBox[{"-", 
        FractionBox[
         RowBox[{"\[Sigma]\[CapitalPhi]", " ", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["sd", "2"], "+", 
            RowBox[{"\[Mu]\[CapitalPhi]", " ", 
             SuperscriptBox["\[Omega]d", "2"]}]}]]}], 
         SqrtBox["\[Mu]\[CapitalPhi]"]]}]},
      {
       RowBox[{
        FractionBox["\[Sigma]Z", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["sd", "2"], "+", 
           SuperscriptBox["\[Omega]d", "2"]}]]], "+", 
        FractionBox[
         RowBox[{
         "\[ImaginaryI]", " ", "\[Sigma]A\[Omega]", " ", "\[Omega]d"}], 
         SqrtBox[
          RowBox[{
           SuperscriptBox["sd", "2"], "+", 
           SuperscriptBox["\[Omega]d", "2"]}]]], "+", 
        FractionBox[
         RowBox[{"\[Sigma]\[CapitalPhi]", " ", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["sd", "2"], "+", 
            RowBox[{"\[Mu]\[CapitalPhi]", " ", 
             SuperscriptBox["\[Omega]d", "2"]}]}]]}], 
         RowBox[{"sd", " ", 
          SqrtBox["\[Mu]\[CapitalPhi]"]}]]}]},
      {
       RowBox[{
        RowBox[{"-", "\[Sigma]Z"}], "-", 
        RowBox[{"\[ImaginaryI]", " ", "\[Sigma]A\[Omega]", " ", "\[Omega]d"}],
         "-", 
        FractionBox[
         RowBox[{"\[Sigma]\[CapitalPhi]", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["sd", "2"], "+", 
            RowBox[{"\[Mu]\[CapitalPhi]", " ", 
             SuperscriptBox["\[Omega]d", "2"]}]}], ")"}]}], 
         RowBox[{"sd", " ", "\[Mu]\[CapitalPhi]"}]]}]},
      {
       RowBox[{"\[Sigma]A\[Omega]", "-", 
        FractionBox[
         RowBox[{
         "\[ImaginaryI]", " ", "\[Sigma]\[CapitalPhi]", " ", "\[Omega]d"}], 
         "sd"]}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"-", "\[Sigma]A\[Omega]"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["sd", "2"], "+", 
           SuperscriptBox["\[Omega]d", "2"]}]]}], "+", 
        FractionBox[
         RowBox[{
         "\[ImaginaryI]", " ", "\[Sigma]\[CapitalPhi]", " ", "\[Omega]d", " ", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["sd", "2"], "+", 
            RowBox[{"\[Mu]\[CapitalPhi]", " ", 
             SuperscriptBox["\[Omega]d", "2"]}]}]]}], 
         RowBox[{"sd", " ", 
          SqrtBox["\[Mu]\[CapitalPhi]"]}]]}]},
      {"\[Sigma]A\[Nu]"},
      {
       RowBox[{
        RowBox[{"-", "\[Sigma]A\[Nu]"}], " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["sd", "2"], "+", 
          SuperscriptBox["\[Omega]d", "2"]}]]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.5717243018217382`*^9, 3.571724306655611*^9}, 
   3.571768483947308*^9, 3.577380697401767*^9, 3.5773808994139633`*^9, 
   3.577380989098971*^9}]
}, Open  ]],

Cell["\<\
The eigenvectors have a special case when  (sd+\[Beta] \[Omega]d) = 0:\
\>", "Text",
 CellChangeTimes->{{3.5717254655064898`*^9, 3.57172551427339*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"M", "//", "Eigenvectors"}], "//", "Det"}], "//", 
    "FullSimplify"}], "//", "PowerExpand"}], "//", "FullSimplify"}]], "Input",\

 CellChangeTimes->{{3.571725433486685*^9, 3.571725460239582*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"16", " ", 
   SuperscriptBox["sd", "2"], " ", 
   SqrtBox["\[Mu]\[CapitalPhi]"]}], 
  RowBox[{
   SuperscriptBox["\[Omega]d", "2"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["sd", "2"], "+", 
      SuperscriptBox["\[Omega]d", "2"]}], ")"}], 
    RowBox[{"3", "/", "2"}]], " ", 
   SqrtBox[
    RowBox[{
     SuperscriptBox["sd", "2"], "+", 
     RowBox[{"\[Mu]\[CapitalPhi]", " ", 
      SuperscriptBox["\[Omega]d", "2"]}]}]]}]]], "Output",
 CellChangeTimes->{{3.5717254399480352`*^9, 3.571725461263002*^9}, 
   3.571768486925269*^9, 3.577380494544434*^9, 3.577380799972871*^9, 
   3.577380899514295*^9, 3.577380989156047*^9}]
}, Open  ]],

Cell["\<\
The solution was constructed elsewhere. The method is just to change \
variables, compute the eigenvectors, transform back. and then simplify as \
much as possible.
The script already constructs it. General Solution:\
\>", "Text",
 CellChangeTimes->{{3.571725586175832*^9, 3.5717256233539143`*^9}, {
  3.571728506751567*^9, 3.571728553984318*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"M", ".", 
           RowBox[{"(", 
            RowBox[{"GenSoln", "-", 
             RowBox[{"(", 
              RowBox[{"GenSoln", "/.", 
               RowBox[{
                RowBox[{"\[Sigma]Vec", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "\[Rule]", "0"}]}], ")"}]}], 
            ")"}]}], "-", 
          RowBox[{
           RowBox[{"Evals", "[", 
            RowBox[{"[", "i", "]"}], "]"}], 
           RowBox[{"(", 
            RowBox[{"GenSoln", "-", 
             RowBox[{"(", 
              RowBox[{"GenSoln", "/.", 
               RowBox[{
                RowBox[{"\[Sigma]Vec", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "\[Rule]", "0"}]}], ")"}]}], 
            ")"}]}]}], "/.", "UnDashTauRules"}], "/.", "UnTauRules"}], "/.", 
       "UnChiRules"}], "/.", "UnLambdaRules"}], "/.", "UnGammaRules"}], "//", 
    "FullSimplify"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "4"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.571724315044922*^9, 3.571724369522621*^9}, {
  3.571724598682007*^9, 3.5717247750929337`*^9}, {3.571724869628141*^9, 
  3.5717248722271967`*^9}, {3.57738082216374*^9, 3.577380831338591*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
     "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
     "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
     "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
     "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.5717246183828287`*^9, 3.5717246352320843`*^9}, {
   3.571724670180407*^9, 3.571724740060108*^9}, 3.571724781372457*^9, 
   3.571724872684906*^9, 3.571768487144668*^9, 3.577380684145545*^9, {
   3.577380797570168*^9, 3.57738082860305*^9}, {3.577380879918185*^9, 
   3.5773808995422287`*^9}, 3.577380989169537*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Substitute the solution into the boundary conditions", "Text",
 CellChangeTimes->{{3.5717256371108637`*^9, 3.5717256626897717`*^9}}],

Cell["Laplace - Fourier the BCs :", "Text",
 CellChangeTimes->{{3.571842556093617*^9, 3.571842566266282*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"BCs", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["sd", "2"], " ", 
        RowBox[{"\[CapitalPhi]", "[", "x", "]"}]}], "-", 
       RowBox[{"2", "  ", "sd", " ", 
        SqrtBox["\[Mu]\[CapitalPhi]"], " ", 
        RowBox[{"D\[CapitalPhi]", "[", "x", "]"}]}], "+", " ", 
       RowBox[{
        SuperscriptBox["\[Kappa]", 
         RowBox[{"-", "1"}]], " ", "\[Mu]\[CapitalPhi]", " ", 
        RowBox[{
         RowBox[{"D\[CapitalPhi]", "'"}], "[", "x", "]"}]}]}], "\[Equal]", 
      RowBox[{"sd", " ", "g\[CapitalPhi]"}]}], ",", " ", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"sd", " ", 
        RowBox[{"Z", "[", "x", "]"}]}], "-", 
       RowBox[{"DZ", "[", "x", "]"}]}], "\[Equal]", " ", 
      RowBox[{"sd", " ", "gZ"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"sd", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"sd", " ", 
           RowBox[{"A\[Omega]", "[", "x", "]"}]}], "+", 
          RowBox[{"I", " ", "\[Omega]d", " ", 
           RowBox[{"\[CapitalPhi]", "[", "x", "]"}]}], "-", 
          RowBox[{"DA\[Omega]", "[", "x", "]"}], "+", 
          RowBox[{"I", " ", "\[Omega]d", " ", 
           RowBox[{"Ax", "[", "x", "]"}]}]}], ")"}]}], "-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"sd", " ", 
          RowBox[{"DA\[Omega]", "[", "x", "]"}]}], "+", 
         RowBox[{"I", " ", "\[Omega]d", " ", 
          RowBox[{"D\[CapitalPhi]", "[", "x", "]"}]}], "-", 
         RowBox[{
          SuperscriptBox["\[Kappa]", 
           RowBox[{"-", "1"}]], 
          RowBox[{
           RowBox[{"DA\[Omega]", "'"}], "[", "x", "]"}]}], "+", 
         RowBox[{"I", " ", "\[Omega]d", " ", 
          RowBox[{"DAx", "[", "x", "]"}]}]}], ")"}]}], "\[Equal]", 
      RowBox[{"sd", " ", "gA\[Omega]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"sd", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"sd", " ", 
           RowBox[{"A\[Nu]", "[", "x", "]"}]}], "-", 
          RowBox[{"DA\[Nu]", "[", "x", "]"}]}], ")"}]}], "-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"sd", " ", 
          RowBox[{"DA\[Nu]", "[", "x", "]"}]}], "-", 
         RowBox[{
          SuperscriptBox["\[Kappa]", 
           RowBox[{"-", "1"}]], 
          RowBox[{
           RowBox[{"DA\[Nu]", "'"}], "[", "x", "]"}]}]}], ")"}]}], "\[Equal]", 
      RowBox[{"sd", " ", "gA\[Nu]"}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.571725752174879*^9, 3.5717257541721582`*^9}, {
   3.571725816246517*^9, 3.5717258868086*^9}, {3.5717259502883577`*^9, 
   3.571725951111492*^9}, {3.571726029121592*^9, 3.571726031456223*^9}, {
   3.571726077585129*^9, 3.571726079345901*^9}, {3.571726145329596*^9, 
   3.5717261803144827`*^9}, {3.571726258059908*^9, 3.571726290675609*^9}, {
   3.5717263471588697`*^9, 3.57172635058923*^9}, {3.57172664022898*^9, 
   3.5717266938372927`*^9}, {3.5717268205647173`*^9, 
   3.5717268347329693`*^9}, {3.571726896485941*^9, 3.571726943620665*^9}, {
   3.5717270044516153`*^9, 3.571727030512347*^9}, {3.5717270613500557`*^9, 
   3.571727067939168*^9}, {3.571727476700487*^9, 3.57172756519072*^9}, 
   3.5717289214728613`*^9, {3.571729002620823*^9, 3.571729004124888*^9}, {
   3.5717292603345003`*^9, 3.571729331601735*^9}, {3.571729364287483*^9, 
   3.5717293694249353`*^9}, {3.57172941393823*^9, 3.571729428192066*^9}, {
   3.571729629839814*^9, 3.571729676028165*^9}, {3.571729730843985*^9, 
   3.571729843957766*^9}, 3.571730000700677*^9, 3.571730062614585*^9, {
   3.571730359558454*^9, 3.571730371339463*^9}, {3.571730410625719*^9, 
   3.571730432148752*^9}, 3.571730552881311*^9, 3.5717306482366323`*^9, {
   3.571730719241186*^9, 3.571730720200417*^9}, {3.5717324743125153`*^9, 
   3.571732554337255*^9}, {3.571732617528737*^9, 3.5717326189155283`*^9}, {
   3.571732776811337*^9, 3.5717327773003883`*^9}, 3.571732987291732*^9, {
   3.571733031417034*^9, 3.571733034132248*^9}, {3.571754231614004*^9, 
   3.5717543433449383`*^9}, {3.571754431661895*^9, 3.5717544318178997`*^9}, {
   3.571754484047374*^9, 3.5717545986526814`*^9}, 3.571755076572403*^9, {
   3.571756228491168*^9, 3.571756240624935*^9}, {3.571757125863782*^9, 
   3.571757150706954*^9}}],

Cell[CellGroupData[{

Cell["A couple of rules for simplification", "Text",
 CellChangeTimes->{{3.571757607929262*^9, 3.571757617137694*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Simp1", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Mu]\[CapitalPhi]", " ", 
        SuperscriptBox["\[Omega]d", "2"]}], "+", 
       RowBox[{"2", " ", "sd", " ", 
        RowBox[{"(", 
         RowBox[{"sd", "+", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["sd", "2"], "+", 
            RowBox[{"\[Mu]\[CapitalPhi]", " ", 
             SuperscriptBox["\[Omega]d", "2"]}]}]]}], ")"}]}]}], "\[Rule]", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"sd", "+", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["sd", "2"], "+", 
           RowBox[{"\[Mu]\[CapitalPhi]", " ", 
            SuperscriptBox["\[Omega]d", "2"]}]}]]}], ")"}], "2"]}], ",", " ", 
     
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Omega]d", "2"], "+", 
       RowBox[{"2", " ", "sd", " ", 
        RowBox[{"(", 
         RowBox[{"sd", "+", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["sd", "2"], "+", 
            SuperscriptBox["\[Omega]d", "2"]}]]}], ")"}]}]}], "\[Rule]", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"sd", "+", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["sd", "2"], "+", 
           SuperscriptBox["\[Omega]d", "2"]}]]}], ")"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[Omega]d", "2"], "+", 
        RowBox[{"2", " ", "sd", " ", 
         RowBox[{"(", 
          RowBox[{"sd", "-", 
           RowBox[{"\[Sqrt]", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["sd", "2"], "+", 
              SuperscriptBox["\[Omega]d", "2"]}], ")"}]}]}], ")"}]}]}], ")"}],
       "\[Rule]", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"sd", "-", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["sd", "2"], "+", 
           SuperscriptBox["\[Omega]d", "2"]}]]}], ")"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[Omega]d", "2"]}], "+", 
        RowBox[{"2", " ", "sd", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "sd"}], "+", 
           SqrtBox[
            RowBox[{
             SuperscriptBox["sd", "2"], "+", 
             SuperscriptBox["\[Omega]d", "2"]}]]}], ")"}]}]}], ")"}], 
      "\[Rule]", 
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"sd", "-", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["sd", "2"], "+", 
            SuperscriptBox["\[Omega]d", "2"]}]]}], ")"}], "2"]}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"sd", "-", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["sd", "2"], "+", 
          SuperscriptBox["\[Omega]d", "2"]}]]}], ")"}], "\[Rule]", 
      FractionBox[
       RowBox[{"-", 
        SuperscriptBox["\[Omega]d", "2"]}], 
       RowBox[{"(", 
        RowBox[{"sd", "+", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["sd", "2"], "+", 
           SuperscriptBox["\[Omega]d", "2"]}]]}], ")"}]]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["sd", "3"]}], "+", 
        RowBox[{"2", " ", "sd", " ", 
         SuperscriptBox["\[Omega]d", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["sd", "2"], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["sd", "2"], "+", 
           SuperscriptBox["\[Omega]d", "2"]}]]}], "-", 
        RowBox[{
         SuperscriptBox["\[Omega]d", "2"], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["sd", "2"], "+", 
           SuperscriptBox["\[Omega]d", "2"]}]]}]}], ")"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "sd"}], "+", 
           SqrtBox[
            RowBox[{
             SuperscriptBox["sd", "2"], "+", 
             SuperscriptBox["\[Omega]d", "2"]}]]}], ")"}], "2"]}], 
       SqrtBox[
        RowBox[{
         SuperscriptBox["sd", "2"], "+", 
         SuperscriptBox["\[Omega]d", "2"]}]]}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["sd", "3"]}], "-", 
        RowBox[{"2", " ", "sd", " ", 
         SuperscriptBox["\[Omega]d", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["sd", "2"], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["sd", "2"], "+", 
           SuperscriptBox["\[Omega]d", "2"]}]]}], "+", 
        RowBox[{
         SuperscriptBox["\[Omega]d", "2"], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["sd", "2"], "+", 
           SuperscriptBox["\[Omega]d", "2"]}]]}]}], ")"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "sd"}], "+", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["sd", "2"], "+", 
            SuperscriptBox["\[Omega]d", "2"]}]]}], ")"}], "2"], 
       SqrtBox[
        RowBox[{
         SuperscriptBox["sd", "2"], "+", 
         SuperscriptBox["\[Omega]d", "2"]}]]}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.571757560531055*^9, 3.571757605643272*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Simp2", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"sd", "-", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["sd", "2"], "+", 
         SuperscriptBox["\[Omega]d", "2"]}]]}], ")"}], "\[Rule]", 
     FractionBox[
      RowBox[{"-", 
       SuperscriptBox["\[Omega]d", "2"]}], 
      RowBox[{"(", 
       RowBox[{"sd", "+", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["sd", "2"], "+", 
          SuperscriptBox["\[Omega]d", "2"]}]]}], ")"}]]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5717576248248453`*^9, 3.571757630481954*^9}}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"BCSoln", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"BCs", "/.", "RHStrafRule"}], "/.", "RHSoldRule"}], "/.",
               "ChangeofVarRuleNewToOld"}], "/.", "GenSolnRule"}], "/.", 
            "UnChiRules"}], "/.", "UnDashTauRules"}], "/.", "UnTauRules"}], "/.",
          "UnGammaRules"}], ")"}], ",", "\[Sigma]Vec"}], "]"}], "//", 
     "Flatten"}], "//", "FullSimplify"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.571725864879706*^9, 3.571725929949027*^9}, {
   3.571725971868126*^9, 3.571725993579198*^9}, {3.571726201316457*^9, 
   3.5717262253061523`*^9}, {3.571726314173263*^9, 3.5717263167563133`*^9}, {
   3.5717275436127443`*^9, 3.571727547412269*^9}, 3.571728696164907*^9, {
   3.5717293511179934`*^9, 3.571729354368408*^9}, {3.5717295506384583`*^9, 
   3.571729572543622*^9}, {3.5717547407585783`*^9, 3.5717547484693317`*^9}, 
   3.571838750392255*^9}],

Cell["Final solution:", "Text",
 CellChangeTimes->{{3.571842580354513*^9, 3.571842594197192*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Collect", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"GenSoln", "/.", "BCSoln"}], "/.", "UnChiRules"}], "/.", 
           "UnDashTauRules"}], "/.", "UnTauRules"}], "/.", "UnGammaRules"}], 
        ",", "bcVec", ",", 
        RowBox[{
         RowBox[{"FullSimplify", "@", 
          RowBox[{"Factor", "@", 
           RowBox[{"FullSimplify", "@", "#"}]}]}], "&"}]}], "]"}], "/.", 
      "Simp1"}], ",", "bcVec", ",", 
     RowBox[{
      RowBox[{"FullSimplify", "@", 
       RowBox[{"Factor", "@", 
        RowBox[{"FullSimplify", "@", "#"}]}]}], "&"}]}], "]"}], "/.", 
   "Simp2"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.571725977612941*^9, 3.571726004049947*^9}, {
   3.5717270889438343`*^9, 3.5717270908802843`*^9}, {3.571727127528055*^9, 
   3.571727129150477*^9}, 3.571727432774518*^9, {3.571729447476408*^9, 
   3.5717294635169163`*^9}, {3.571729518421193*^9, 3.5717295204685183`*^9}, {
   3.571730292563847*^9, 3.57173031906085*^9}, {3.571730513739339*^9, 
   3.571730513949041*^9}, {3.5717310785936823`*^9, 3.5717310837918386`*^9}, {
   3.571754907799711*^9, 3.571754910454124*^9}, {3.571754961674222*^9, 
   3.571754973883505*^9}, {3.571755165577731*^9, 3.571755165818388*^9}, {
   3.571755296576373*^9, 3.571755296926916*^9}, {3.5717554291295443`*^9, 
   3.571755429347597*^9}, {3.571755723225721*^9, 3.5717557246238203`*^9}, {
   3.5717560870830183`*^9, 3.571756087338847*^9}, {3.571756128362954*^9, 
   3.571756185488586*^9}, {3.571756280162772*^9, 3.571756305404258*^9}, {
   3.571757546437958*^9, 3.571757569685412*^9}, {3.571757656223765*^9, 
   3.571757667721047*^9}, 3.5773809518461103`*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       FractionBox[
        RowBox[{"g\[CapitalPhi]", " ", "sd"}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"sd", "+", 
           SqrtBox[
            RowBox[{
             SuperscriptBox["sd", "2"], "+", 
             RowBox[{"\[Mu]\[CapitalPhi]", " ", 
              SuperscriptBox["\[Omega]d", "2"]}]}]]}], ")"}], "2"]]},
      {
       RowBox[{"-", 
        FractionBox[
         RowBox[{"g\[CapitalPhi]", " ", "sd", " ", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["sd", "2"], "+", 
            RowBox[{"\[Mu]\[CapitalPhi]", " ", 
             SuperscriptBox["\[Omega]d", "2"]}]}]]}], 
         RowBox[{
          SqrtBox["\[Mu]\[CapitalPhi]"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"sd", "+", 
             SqrtBox[
              RowBox[{
               SuperscriptBox["sd", "2"], "+", 
               RowBox[{"\[Mu]\[CapitalPhi]", " ", 
                SuperscriptBox["\[Omega]d", "2"]}]}]]}], ")"}], "2"]}]]}]},
      {
       RowBox[{
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", "gA\[Omega]", " ", "\[Omega]d"}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"sd", "+", 
            SqrtBox[
             RowBox[{
              SuperscriptBox["sd", "2"], "+", 
              SuperscriptBox["\[Omega]d", "2"]}]]}], ")"}], "2"]], "+", 
        FractionBox["gZ", 
         RowBox[{"sd", "+", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["sd", "2"], "+", 
            SuperscriptBox["\[Omega]d", "2"]}]]}]], "+", 
        FractionBox[
         RowBox[{"g\[CapitalPhi]", " ", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["sd", "2"], "+", 
            RowBox[{"\[Mu]\[CapitalPhi]", " ", 
             SuperscriptBox["\[Omega]d", "2"]}]}]]}], 
         RowBox[{
          SqrtBox["\[Mu]\[CapitalPhi]"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"sd", "+", 
             SqrtBox[
              RowBox[{
               SuperscriptBox["sd", "2"], "+", 
               RowBox[{"\[Mu]\[CapitalPhi]", " ", 
                SuperscriptBox["\[Omega]d", "2"]}]}]]}], ")"}], "2"]}]]}]},
      {
       RowBox[{
        RowBox[{"-", 
         FractionBox["gZ", 
          RowBox[{"1", "+", 
           FractionBox["sd", 
            SqrtBox[
             RowBox[{
              SuperscriptBox["sd", "2"], "+", 
              SuperscriptBox["\[Omega]d", "2"]}]]]}]]}], "-", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", "gA\[Omega]", " ", "\[Omega]d", " ", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["sd", "2"], "+", 
            SuperscriptBox["\[Omega]d", "2"]}]]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"sd", "+", 
            SqrtBox[
             RowBox[{
              SuperscriptBox["sd", "2"], "+", 
              SuperscriptBox["\[Omega]d", "2"]}]]}], ")"}], "2"]], "-", 
        FractionBox[
         RowBox[{"g\[CapitalPhi]", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["sd", "2"], "+", 
            RowBox[{"\[Mu]\[CapitalPhi]", " ", 
             SuperscriptBox["\[Omega]d", "2"]}]}], ")"}]}], 
         RowBox[{"\[Mu]\[CapitalPhi]", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"sd", "+", 
             SqrtBox[
              RowBox[{
               SuperscriptBox["sd", "2"], "+", 
               RowBox[{"\[Mu]\[CapitalPhi]", " ", 
                SuperscriptBox["\[Omega]d", "2"]}]}]]}], ")"}], "2"]}]]}]},
      {
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"\[ImaginaryI]", " ", "gZ", " ", "\[Omega]d"}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"sd", "+", 
             SqrtBox[
              RowBox[{
               SuperscriptBox["sd", "2"], "+", 
               SuperscriptBox["\[Omega]d", "2"]}]]}], ")"}], "2"]]}], "+", 
        FractionBox[
         RowBox[{"gA\[Omega]", " ", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["sd", "2"], "+", 
            SuperscriptBox["\[Omega]d", "2"]}]]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"sd", "+", 
            SqrtBox[
             RowBox[{
              SuperscriptBox["sd", "2"], "+", 
              SuperscriptBox["\[Omega]d", "2"]}]]}], ")"}], "2"]], "-", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", "g\[CapitalPhi]", " ", "\[Omega]d"}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"sd", "+", 
            SqrtBox[
             RowBox[{
              SuperscriptBox["sd", "2"], "+", 
              RowBox[{"\[Mu]\[CapitalPhi]", " ", 
               SuperscriptBox["\[Omega]d", "2"]}]}]]}], ")"}], "2"]]}]},
      {
       RowBox[{
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", "gZ", " ", "\[Omega]d", " ", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["sd", "2"], "+", 
            SuperscriptBox["\[Omega]d", "2"]}]]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"sd", "+", 
            SqrtBox[
             RowBox[{
              SuperscriptBox["sd", "2"], "+", 
              SuperscriptBox["\[Omega]d", "2"]}]]}], ")"}], "2"]], "-", 
        FractionBox[
         RowBox[{"gA\[Omega]", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["sd", "2"], "+", 
            SuperscriptBox["\[Omega]d", "2"]}], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"sd", "+", 
            SqrtBox[
             RowBox[{
              SuperscriptBox["sd", "2"], "+", 
              SuperscriptBox["\[Omega]d", "2"]}]]}], ")"}], "2"]], "+", 
        FractionBox[
         RowBox[{
         "\[ImaginaryI]", " ", "g\[CapitalPhi]", " ", "\[Omega]d", " ", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["sd", "2"], "+", 
            RowBox[{"\[Mu]\[CapitalPhi]", " ", 
             SuperscriptBox["\[Omega]d", "2"]}]}]]}], 
         RowBox[{
          SqrtBox["\[Mu]\[CapitalPhi]"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"sd", "+", 
             SqrtBox[
              RowBox[{
               SuperscriptBox["sd", "2"], "+", 
               RowBox[{"\[Mu]\[CapitalPhi]", " ", 
                SuperscriptBox["\[Omega]d", "2"]}]}]]}], ")"}], "2"]}]]}]},
      {
       FractionBox[
        RowBox[{"gA\[Nu]", " ", "sd"}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"sd", "+", 
           SqrtBox[
            RowBox[{
             SuperscriptBox["sd", "2"], "+", 
             SuperscriptBox["\[Omega]d", "2"]}]]}], ")"}], "2"]]},
      {
       RowBox[{"-", 
        FractionBox[
         RowBox[{"gA\[Nu]", " ", "sd", " ", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["sd", "2"], "+", 
            SuperscriptBox["\[Omega]d", "2"]}]]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"sd", "+", 
            SqrtBox[
             RowBox[{
              SuperscriptBox["sd", "2"], "+", 
              SuperscriptBox["\[Omega]d", "2"]}]]}], ")"}], "2"]]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.571725981580428*^9, 3.5717260331722717`*^9}, 
   3.571726227550132*^9, 3.571726321066551*^9, {3.571726353842997*^9, 
   3.571726378974025*^9}, 3.5717266980991163`*^9, {3.571726782935924*^9, 
   3.571726785809585*^9}, {3.5717269247211246`*^9, 3.5717269620481577`*^9}, 
   3.57172703943552*^9, {3.571727070955968*^9, 3.571727092752603*^9}, 
   3.571727129715007*^9, {3.571727391465139*^9, 3.5717274330197363`*^9}, {
   3.5717275489293623`*^9, 3.57172756698193*^9}, {3.5717286934126053`*^9, 
   3.571728698718973*^9}, 3.57172892625852*^9, 3.571729079350931*^9, 
   3.5717294027581244`*^9, {3.571729436951766*^9, 3.571729464237756*^9}, {
   3.571729515289016*^9, 3.5717295225909653`*^9}, 3.57172957398962*^9, 
   3.571729682603004*^9, 3.5717298072409573`*^9, 3.571729850182954*^9, 
   3.5717298906774883`*^9, 3.571730002960471*^9, 3.571730064636251*^9, {
   3.5717303001169786`*^9, 3.571730319970776*^9}, 3.571730373239621*^9, {
   3.571730415947835*^9, 3.571730434186311*^9}, 3.571730514536551*^9, 
   3.571730555139851*^9, 3.571730649893821*^9, 3.5717307233825197`*^9, 
   3.571731084048025*^9, 3.571732323537179*^9, {3.5717325125821323`*^9, 
   3.571732557892995*^9}, 3.5717327810655947`*^9, 3.5717329896141777`*^9, 
   3.571733036169167*^9, 3.571754345376892*^9, 3.571754433502948*^9, 
   3.571754486986124*^9, 3.571754601525668*^9, 3.5717546812898293`*^9, 
   3.571754750299556*^9, 3.571754911026395*^9, 3.571754974752295*^9, 
   3.571755078493596*^9, 3.571755166409831*^9, 3.57175529783387*^9, 
   3.571755429956283*^9, 3.571756088676962*^9, {3.571756129023529*^9, 
   3.571756146972465*^9}, 3.571756186670179*^9, 3.571756242869961*^9, 
   3.5717563063667316`*^9, {3.571757141956019*^9, 3.571757152606831*^9}, {
   3.571757546980229*^9, 3.5717575556760674`*^9}, {3.5717576681152973`*^9, 
   3.5717576790769672`*^9}, {3.571768493123919*^9, 3.571768493369871*^9}, {
   3.571838736450261*^9, 3.5718387657996407`*^9}, 3.57738092973499*^9, 
   3.5773809892800703`*^9},
 FontSize->18]
}, Open  ]]
}, Closed]]
},
CellGrouping->Manual,
WindowSize->{1600, 851},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"8.0 for Linux x86 (64-bit) (February 23, 2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 96, 1, 30, "Input"],
Cell[656, 23, 272, 6, 87, "Subtitle"],
Cell[CellGroupData[{
Cell[953, 33, 172, 3, 30, "Text",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[1128, 38, 722, 11, 30, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Closed]],
Cell[CellGroupData[{
Cell[1887, 54, 175, 4, 27, "Text"],
Cell[CellGroupData[{
Cell[2087, 62, 175, 3, 30, "Input"],
Cell[2265, 67, 2400, 62, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[4714, 135, 172, 2, 27, "Text"],
Cell[CellGroupData[{
Cell[4911, 141, 131, 2, 30, "Input"],
Cell[5045, 145, 3407, 99, 70, "Output"]
}, Open  ]],
Cell[8467, 247, 161, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[8653, 254, 270, 8, 30, "Input"],
Cell[8926, 264, 701, 20, 70, "Output"]
}, Open  ]],
Cell[9642, 287, 357, 7, 49, "Text"],
Cell[CellGroupData[{
Cell[10024, 298, 1331, 36, 50, "Input"],
Cell[11358, 336, 908, 23, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[12315, 365, 138, 1, 27, "Text"],
Cell[12456, 368, 109, 1, 30, "Text"],
Cell[12568, 371, 4314, 94, 120, "Input"],
Cell[CellGroupData[{
Cell[16907, 469, 118, 1, 30, "Text"],
Cell[17028, 472, 5321, 167, 195, "Input"],
Cell[22352, 641, 628, 21, 86, "Input"]
}, Open  ]],
Cell[22995, 665, 1117, 26, 30, "Input"],
Cell[24115, 693, 97, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[24237, 698, 1802, 38, 50, "Input"],
Cell[26042, 738, 9763, 255, 506, "Output"]
}, Open  ]]
}, Closed]]
}
]
*)

(* End of internal cache information *)
